@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        toolchain.lua
@@ -521,6 +521,11 @@ function _instance:_checktool(toolkind, toolpath)
     if tool then
         program = tool.program
         toolname = toolname or tool.name
+    else
+        -- we need reset result if not found
+        -- https://github.com/xmake-io/xmake/discussions/6415#discussioncomment-13099816
+        program = nil
+        toolname = nil
     end
 
     -- get tool description from the tool kind
